FromBytesWithNulError

Enum FromBytesWithNulError 

1.10.0 · Source
pub enum FromBytesWithNulError {
    InteriorNul {
        position: usize,
    },
    NotNulTerminated,
}
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
An error indicating that a nul byte was not in the expected position.

The slice used to create a CStr must have one and only one nul byte, positioned at the end.

This error is created by the CStr::from_bytes_with_nul method. See its documentation for more.

Examples

use std::ffi::{CStr, FromBytesWithNulError};

let _: FromBytesWithNulError = CStr::from_bytes_with_nul(b"f\0oo").unwrap_err();

Variants

1.64.0

InteriorNul

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Data provided contains an interior nul byte at byte position.

Fields

position: usize
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

The position of the interior nul byte.

1.64.0

NotNulTerminated

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Data provided is not nul terminated.